<?php
/*
Plugin Name: Contact Form 7 Inwise Integration
Description: Integrates Contact Form 7 with Inwise for lead acquisition.
Version: 1.8
Author: Your Name
*/

// Add settings menu
add_action('admin_menu', 'cf7_inwise_settings_menu');
function cf7_inwise_settings_menu() {
    add_options_page('CF7 Inwise Settings', 'CF7 Inwise', 'manage_options', 'cf7-inwise', 'cf7_inwise_settings_page');
    add_submenu_page('cf7-inwise', 'Merge Fields', 'Merge Fields', 'manage_options', 'cf7-inwise-merge-fields', 'cf7_inwise_merge_fields_page');
}

// Register settings
add_action('admin_init', 'cf7_inwise_register_settings');
function cf7_inwise_register_settings() {
    register_setting('cf7_inwise_settings_group', 'cf7_inwise_api_key');
}

// Settings page HTML
function cf7_inwise_settings_page() {
    ?>
    <div class="wrap">
        <h1>Contact Form 7 Inwise Integration</h1>
        <form method="post" action="options.php">
            <?php settings_fields('cf7_inwise_settings_group'); ?>
            <?php do_settings_sections('cf7_inwise_settings_group'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Inwise API Key</th>
                    <td><input type="text" name="cf7_inwise_api_key" value="<?php echo esc_attr(get_option('cf7_inwise_api_key')); ?>" /></td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Add Inwise field to Contact Form 7
add_filter('wpcf7_editor_panels', 'cf7_inwise_add_field_editor_panel');
function cf7_inwise_add_field_editor_panel($panels) {
    $panels['inwise-integration-panel'] = array(
        'title' => __('Inwise Integration', 'contact-form-7'),
        'callback' => 'cf7_inwise_editor_panel_content'
    );

    $panels['inwise-merge-fields-panel'] = array(
        'title' => __('Inwise Fields Map', 'contact-form-7'),
        'callback' => 'cf7_inwise_merge_fields_panel_content'
    );

    return $panels;
}

function cf7_inwise_editor_panel_content($post) {
    $inwise_group_id = get_post_meta($post->id(), '_cf7_inwise_group_id', true);
    ?>
    <h2><?php _e('Inwise Integration', 'contact-form-7'); ?></h2>
    <p>
        <label for="cf7-inwise-group-id"><?php _e('Inwise Group ID:', 'contact-form-7'); ?></label>
        <input type="text" id="cf7-inwise-group-id" name="cf7_inwise_group_id" value="<?php echo esc_attr($inwise_group_id); ?>" />
    </p>
    <?php
}

function cf7_inwise_merge_fields_panel_content($post) {
    ?>
    <h2><?php _e('Inwise Fields Map', 'contact-form-7'); ?></h2>
    <?php
    $response = wp_remote_get('https://api.inwise.com/rest/v1/contacts/mergeFields', array(
        'headers' => array(
            'Accept' => 'application/json',
            'X-API-Key' => get_option('cf7_inwise_api_key')
        )
    ));

    if (is_wp_error($response)) {
        echo '<p>Error retrieving merge fields: ' . $response->get_error_message() . '</p>';
        error_log('Inwise Merge Fields Error: ' . $response->get_error_message());
    } else {
        $body = wp_remote_retrieve_body($response);
        $data = json_decode($body, true);

        if (is_array($data)) {
            echo '<table class="widefat">';
            echo '<thead><tr><th>ID</th><th>Description</th><th>Type</th><th>Options</th></tr></thead>';
            echo '<tbody>';
echo '<tr><td>'. 'email_address'.'</td><td>כתובת אימייל</td><td>email</td>';
echo '<tr><td>'. 'mobile_number'.'</td><td>טלפון</td><td>tel</td>';
            foreach ($data as $field) {
                echo '<tr>';
                echo '<td>' . esc_html($field['id']) . '</td>';
                echo '<td>' . esc_html($field['description']) . '</td>';
                echo '<td>' . esc_html($field['type']) . '</td>';
                echo '<td>';
                if (isset($field['options']) && is_array($field['options'])) {
                    echo implode(', ', array_map('esc_html', $field['options']));
                } else {
                    echo '-';
                }
                echo '</td>';
                echo '</tr>';
            }
            echo '</tbody>';
            echo '</table>';
        } else {
            echo '<p>No merge fields found.</p>';
        }
    }
    ?>
    <?php
}

// Save Inwise group ID with form
add_action('wpcf7_save_contact_form', 'cf7_inwise_save_contact_form');
function cf7_inwise_save_contact_form($post) {
    if (isset($_POST['cf7_inwise_group_id'])) {
        update_post_meta($post->id(), '_cf7_inwise_group_id', sanitize_text_field($_POST['cf7_inwise_group_id']));
    }
}

function add_inwise_code_to_admin_footer() {
    ?>
    <script>
        jQuery(document).ready(function($) {
return;
if(jQuery('.contact-form-editor-panel').length==0) return;
if (jQuery('.inwiserow').length == 0) jQuery('.tag-generator-panel tr').parent().append('<tr class="inwiserow"><th scope="row"><label for="tag-generator-panel-text-class">Inwise Field ID</label></th><td><input type="text" class="inwisevalue oneline option"></td></tr>')

jQuery('.inwiserow .inwisevalue').change(function () {
var inwisefieldid = jQuery(this).val()
const regex = /inwise-field:\w+/g;
var code = jQuery('#TB_ajaxContent > form > div.insert-box > input').val()
//prevent undefined
code = code.replace(regex, '');
code = code.substring(0, code.length - 1) + ' inwise-field:' + inwisefieldid + code.substring(code.length - 1)
code = code.replace(/\s+/g, ' ')
jQuery('#TB_ajaxContent > form > div.insert-box > input').val(code)

})

setInterval(function () {
var thecode = jQuery('#TB_ajaxContent > form > div.insert-box > input').val()
if (thecode) {
if (thecode.indexOf('undefined') > 0) {
thecode = thecode.replaceAll('undefined', 'inwise-field')
jQuery('#TB_ajaxContent > form > div.insert-box > input').val(thecode)
}
}
}, 300)



        });
    </script>
    <?php
}
add_action('admin_footer', 'add_inwise_code_to_admin_footer');


// Hook into form submission
add_action('wpcf7_before_send_mail', 'cf7_inwise_integration');
function cf7_inwise_integration($contact_form) {
    $api_key = get_option('cf7_inwise_api_key');
    if (!$api_key) return;

    $group_id = get_post_meta($contact_form->id(), '_cf7_inwise_group_id', true);
    if (!$group_id) return;

    $submission = WPCF7_Submission::get_instance();
    if ($submission) {
        $posted_data = $submission->get_posted_data();
        $form = WPCF7_ContactForm::get_current();
        $form_tags = $form->scan_form_tags();

        $data = array(
            'add_to_groups_ids' => array(intval($group_id)),

        );

        foreach ($form_tags as $tag) {
            if (isset($tag['options'])) {
                foreach ($tag['options'] as $option) {
                    if (preg_match('/class:(\S+)/', $option, $matches)) {
                        $inwise_field = $matches[1];
                        $field_name = $tag['name'];
                        if (isset($posted_data[$field_name])) {
                            if ($inwise_field === 'email_address') {
                                $data['email'] = sanitize_email($posted_data[$field_name]);
                            } elseif ($inwise_field === 'mobile_number') {
                                $phone = sanitize_text_field($posted_data[$field_name]);
$phone = preg_replace('/^0/', '972', $phone);
$phone =  str_replace('-', '', $phone);
                                $data['mobile_number'] = $phone;
                               
                            } else {
                                $data['fields'][] = array(
                                    'name' => sanitize_text_field(str_replace('inwisefield','',$inwise_field)),
                                    'content' => sanitize_text_field($posted_data[$field_name])
                                );
                            }
                        }
                    }
                }
            }
        }

        // Send data to Inwise
        $response = wp_remote_post('https://api.inwise.com/rest/v1/contacts', array(
            'headers' => array(
                'Content-Type' => 'application/json',
                'Accept' => 'application/json',
                'X-API-Key' => $api_key
            ),
            'body' => json_encode($data)
        ));

        if (is_wp_error($response)) {
            $error_message = 'Inwise API Error: ' . $response->get_error_message();
            wpcf7_add_error_message($error_message);
        } elseif (wp_remote_retrieve_response_code($response) != 200) {
            $error_body = wp_remote_retrieve_body($response);
            $error_data = json_decode($error_body, true);
            $error_message = isset($error_data['message']) ? $error_data['message'] : 'Unknown error from Inwise API.';
            wpcf7_add_error_message('Inwise API Error: ' . $error_message);
        }
    }
}

function wpcf7_add_error_message($message) {
    add_action('wpcf7_enqueue_scripts', function() use ($message) {
        echo '<script type="text/javascript">document.addEventListener("DOMContentLoaded", function() { alert("' . esc_js($message) . '"); });</script>';
    });
}
?>